==> 0.1.0.tar.gz: lib/form_companion_presenter.dart <==
// See LICENCE file in the root.

library form_companion_presenter;

export 'src/async_validator_executor.dart'
    show
        AsyncValidator,
        AsyncValidatorOptions,
        AsyncValidationCompletionCallback,
        AsyncValidationFailureHandler,
        AsyncValidatorExecutor,
        ValidationInvocation;
export 'src/form_companion_mixin.dart'
    show
        AsyncValidatorFactory,
        CompanionPresenterFeatures,
        CompanionPresenterMixin,
        CompanionPresenterMixinExtension,
        FormCompanionMixin,
        FormCompanionPropertyDescriptorsBuilderExtension,
        FormFieldValidatorFactory,
        FormStateAdapter,
        PropertyDescriptor,
        PropertyDescriptorsBuilder;
export 'src/future_invoker.dart'
    show
        AsyncErrorHandler,
        AsyncInvocationFailureContext,
        AsyncOperationCompletedCallback,
        AsyncOperationFailedCallback,
        AsyncOperationProgressCallback,
        AsyncOperationFailureHandler,
        AsyncOperationNotifier,
        AsyncOperationStatus,
        FutureInvoker;
export 'src/number_converter.dart'
    show bigIntDoubleConverter, intDoubleConverter;
export 'src/string_converter.dart'
    show
        ParseFailureMessageProvider,
        Parser,
        StringConverter,
        Stringifier,
        bigIntStringConverter,
        dateTimeStringConverter,
        doubleStringConverter,
        intStringConverter,
        uriStringConverter;
export 'src/value_converter.dart'
    show
        ConversionResult,
        FailureResult,
        FieldToPropertyConverter,
        PropertyToFieldConverter,
        SomeConversionResult,
        ValueConverter;

// for testing
// Enable this line to take effect logs in tests in form_builder_companion_presenter package.
// export 'src/internal_utils.dart' show loggerSink, Logger, LogLevel, LoggerSink;

==> 0.4.0.tar.gz: lib/form_companion_presenter.dart <==
// See LICENCE file in the root.

library form_companion_presenter;

export 'src/async_validator_executor.dart'
    show
        AsyncValidator,
        AsyncValidatorOptions,
        AsyncValidationCompletionCallback,
        AsyncValidationFailureHandler,
        AsyncValidatorExecutor,
        ValidationInvocation;
export 'src/form_companion_mixin.dart'
    show
        AsyncValidatorFactory,
        CompanionPresenterFeatures,
        CompanionPresenterMixin,
        CompanionPresenterMixinExtension,
        FormCompanionMixin,
        FormCompanionPropertyDescriptorsBuilderExtension,
        FormFieldValidatorFactory,
        FormProperties,
        FormPropertiesExtension,
        FormStateAdapter,
        OnPropertiesChangedEvent,
        PropertyDescriptor,
        PropertyDescriptorsBuilder,
        ValidatorCreationOptions,
        createValidatorCreationOptions;
export 'src/future_invoker.dart'
    show
        AsyncErrorHandler,
        AsyncInvocationFailureContext,
        AsyncOperationCompletedCallback,
        AsyncOperationFailedCallback,
        AsyncOperationProgressCallback,
        AsyncOperationFailureHandler,
        AsyncOperationNotifier,
        AsyncOperationStatus,
        FutureInvoker;
export 'src/number_converter.dart'
    show bigIntDoubleConverter, intDoubleConverter;
export 'src/string_converter.dart'
    show
        ParseFailureMessageProvider,
        Parser,
        StringConverter,
        Stringifier,
        bigIntStringConverter,
        dateTimeStringConverter,
        doubleStringConverter,
        intStringConverter,
        uriStringConverter;
export 'src/value_converter.dart'
    show
        ConversionResult,
        FailureResult,
        FieldToPropertyConverter,
        PropertyToFieldConverter,
        SomeConversionResult,
        ValueConverter;

// for testing
// Enable this line to take effect logs in tests in form_builder_companion_presenter package.
// export 'src/internal_utils.dart' show loggerSink, Logger, LogLevel, LoggerSink;
